@@ -1,20 +1,21 @@
+#!/usr/bin/env python
+# 2013-11-08: Below, you find  just a code snippet from the first tests.. Examples will be added very soon
+
+
+# Example 1: calculate the mean scalar wind speed of the first 10 layers
 import pynacolada as pcl
 from Scientific.IO import NetCDF
-import os
 import numpy as np
-import pylab as pl
-
-R = 287.058
 
 fnin = '/home/hendrik/data/belgium_aq/rcm/aq09/stage1/int2lm/laf2009010100_urb_ahf.nc'
 #print fnin
 # fobjin = open(fnin,'rb')
 fin = NetCDF.NetCDFFile(fnin,'r')
-fnout = '/home/hendrik/data/belgium_aq/rcm/aq09/stage1/int2lm/laf2009010100_urb_ahf3.nc'
-os.system('rm '+fnout)
+fnout = 'laf2009010100_out.nc'
 #print fnout
 # fobjout = open(fnout,'wb+''rlat')
 fout = NetCDF.NetCDFFile(fnout,'w')
+# input data definitions
 datin =  [{'file': fin, \
            'varname': 'U', \
            'dsel': {'level' : range(30,40,1)}, \
@@ -26,18 +27,11 @@ datin =  [{'file': fin, \
            'daliases': { 'srlat':'rlat', 'srlon':'rlon' },\
            }\
          ]
+# output data definitions
 datout = [{'file': fout, \
            'varname': 'u'}]
-# selection of function dimension input
-func = lambda U,V: np.sqrt(U**2+V**2) 
+# function definition:
+func = lambda U,V: np.array([np.mean(np.sqrt(U**2+V**2),axis=0 )])
 dnamsel = ['level',]
 pcl.pcl(func,dnamsel,datin,datout,appenddim=True)
-
-fout.close()
-
-
-fig = pl.figure()
-fout = NetCDF.NetCDFFile(fnout,'r')
-pl.imshow(fout.variables['T'][:].squeeze())
-fig.show()
-fout.close()
+print 'output data written to:',fnout
