@@ -1,7 +1,7 @@
 import os
 from operator import itemgetter
-import netcdf 
 import numpy as np
+from netcdf import netcdf_file
 import sys 
 from operator import mul
 from ncdftools import nccopydimension
@@ -205,7 +205,7 @@ def pcl(func,dnamsel,datin,datout,appenddim = False, predim = None,maxmembytes =
         vsdin.append(dict())
         if str(type(datin[idatin]['file']))[7:11] == 'list':
             ncfn =  datin[idatin]['file'][0]
-            nctemp = netcdf.netcdf_file(ncfn,'r')
+            nctemp = netcdf_file(ncfn,'r')
             vsdin[idatin]['dnams'] = []
             for idim in range(len(nctemp.variables[datin[idatin]['varname']].dimensions)):
                 edim = nctemp.variables[datin[idatin]['varname']].dimensions[idim]
@@ -242,7 +242,7 @@ def pcl(func,dnamsel,datin,datout,appenddim = False, predim = None,maxmembytes =
                 ncfn = datin[idatin]['file']
             else:
                 raise SomeError("Input file "+ str(datin[idatin]) + " ("+str(idatin)+")  could not be recognized.")
-            nctemp = netcdf.netcdf_file(ncfn,'r')
+            nctemp = netcdf_file(ncfn,'r')
             vsdin[idatin]['dnams'] = []
             for idim in range(len(nctemp.variables[datin[idatin]['varname']].dimensions)):
                 edim = nctemp.variables[datin[idatin]['varname']].dimensions[idim]
@@ -250,11 +250,11 @@ def pcl(func,dnamsel,datin,datout,appenddim = False, predim = None,maxmembytes =
                     if edim in datin[idatin]['daliases']:
                         edim = datin[idatin]['daliases'][edim]
                 vsdin[idatin]['dnams'].append(str(edim))
+            vsdin[idatin]['dims'] = list(nctemp.variables[datin[idatin]['varname']].shape)
 
         vsdin[idatin]['itemsize'] = nctemp.variables[datin[idatin]['varname']].itemsize()
         vsdin[idatin]['dtype']  =   nctemp.variables[datin[idatin]['varname']]._dtype
         vsdin[idatin]['voffset']  = nctemp.variables[datin[idatin]['varname']]._voffset
-        vsdin[idatin]['dims'] = list(nctemp.variables[datin[idatin]['varname']].shape)
 
         # dselmarker
         vsdin[idatin]['dsel'] = [False]*len(vsdin[idatin]['dims'])
@@ -572,7 +572,7 @@ def pcl(func,dnamsel,datin,datout,appenddim = False, predim = None,maxmembytes =
         vsdout[idatout]['fp'] = open(ncfn,'r+')
     
         # in order to discover variable offsets
-        nctemp = netcdf.netcdf_file(ncfn,'r')
+        nctemp = netcdf_file(ncfn,'r')
         vsdout[idatout]['itemsize'] = nctemp.variables[datout[idatout]['varname']].itemsize()
         vsdout[idatout]['voffset'] = nctemp.variables[datout[idatout]['varname']]._voffset
         nctemp.close()
